For some point process models, it is possible to
write down a mathematical expression for the \(K\) function
or the pair correlation function of the model.
The commands Kmodel, Lmodel and pcfmodel are
generic, with methods for the classes "kppm" (fitted cluster processes
and Cox processes), "ppm" (fitted Gibbs processes),
and "clusterprocess" (theoretical cluster processes).
This page documents the methods for the class "clusterprocess".
An object of this class represents a
Neyman-Scott-Cox cluster point process model with specified values
of its parameters.
The return value is a function in the R language,
which takes one argument r.
Evaluation of this function, on a numeric vector r,
yields values of the desired \(K\) function or pair correlation
function at these distance values.