Learn R Programming

spatstat.model (version 3.7-2)

clusterstrength: Cluster Strength Index

Description

Calculate the cluster strength index \(\varphi\) for a cluster point process or Cox point process model.

Usage

clusterstrength(object)

Value

A single numerical value greater than or equal to zero.

Arguments

object

Clustered point process model. Either an object of class "kppm" representing a cluster point process or Cox point process model fitted to point pattern data, or an object of class "clusterprocess" representing a cluster process model with specified parameters.

Author

Adrian Baddeley Adrian.Baddeley@curtin.edu.au.

Details

The cluster strength index of a cluster process model is a numerical index which expresses the strength of clustering. It is defined as (Baddeley et al., 2022, section 10.2) $$ \varphi = g(0)-1 $$ where \(g\) is the pair correlation function of the cluster process.

The index \(\varphi\) is dimensionless and takes non-negative values. Values close to zero indicate that the process is close to a Poisson process.

For a cluster process, \(\varphi\) is related to the sibling probability \(p\) by \(p = \varphi/(1+\varphi)\).

For a Cox process with driving random intensity \(\Lambda(x)\), $$ \varphi = \frac{\mbox{var}(\Lambda(0))}{E[\Lambda(0)]^2} $$ is a measure of the variability of the random intensity.

References

Baddeley, A., Davies, T.M., Hazelton, M.L., Rakshit, S. and Turner, R. (2022) Fundamental problems in fitting spatial cluster process models. Spatial Statistics 52, 100709. DOI: 10.1016/j.spasta.2022.100709

See Also

psib, panysib, persist, repul

Examples

Run this code
  #' Fit a model to the clustered region of full redwood data
  X <- redwoodfull[redwoodfull.extra$regionII]
  fit <- kppm(X)
  clusterstrength(fit)

  #' Create a Thomas model
  m <- clusterprocess("Thomas", kappa=10, mu=5, scale=0.1)
  clusterstrength(m)

Run the code above in your browser using DataLab