Learn R Programming

spatstat.model (version 3.7-2)

intensity.kppm: Intensity of Fitted Point Process Model (Cluster Process or Cox Process)

Description

Computes the intensity of a fitted point process model (Neyman-Scott cluster process or Cox process).

Usage

# S3 method for kppm
intensity(X, ...)

Value

A numeric value (if the model is stationary) or a pixel image.

Arguments

X

A fitted point process model (object of class "kppm").

...

Arguments passed to predict.ppm in some cases. See Details.

Author

Adrian Baddeley Adrian.Baddeley@curtin.edu.au, Rolf Turner rolfturner@posteo.net and Ege Rubak rubak@math.aau.dk.

Details

This is a method for the generic function intensity for fitted point process models of class "kppm". An object of this class is created by the model-fitting function kppm and represents a fitted Neyman-Scott cluster process or Cox process model (Baddeley, Rubak and Turner, 2015, chapter 12).

The intensity of a point process model is the expected number of random points per unit area.

The result of intensity.kppm(X) is a numerical value if X is a stationary point process, and a pixel image if X is non-stationary. In the latter case, the resolution of the pixel image is controlled by the arguments ... which are passed to predict.ppm.

References

Baddeley, A., Rubak, E. and Turner, R. (2015) Spatial Point Patterns: Methodology and Applications with R. Chapman and Hall/CRC Press.

See Also

intensity, intensity.ppm

Examples

Run this code
   m <- kppm(redwood ~ 1, "LGCP")
   intensity(m)

Run the code above in your browser using DataLab