The spatial persistence index of a cluster process model
is a numerical index which expresses the spatial scale of the model
relative to the size of the window in which the data were observed.
It is defined as (Baddeley et al., 2022, section 10.2)
$$
v = \frac{g(d) - 1}{g(0)-1}
$$
where \(g\) is the pair correlation function of the
cluster process, and \(d\) is the diameter of the window.
The index \(v\) is dimensionless and takes values between 0 and 1.
It depends on both the fitted cluster process, and on the
window in which the original data were observed.
(The user can specify a different observation window W,
for which the persistence index should be calculated.)
The spatial persistence index effectively measures the
size of a typical cluster in the cluster process
(observed within the observation window)
as a fraction of the size of the observation window.
Values of \(v\) close to 1 indicate that the
clusters are so large that the model (observed within the observation window)
is effectively a mixed Poisson process.
The spatial persistence index is calculated for the window
specified by the argument W. For a model of class
"kppm", the default for W is the window of the
original point pattern dataset to which the model was fitted.
For a model of class "clusterprocess", the argument W
must be provided.