The repulsiveness index \(\mu\) of a
point process model was defined by Lavancier, Moller and Rubak (2015) as
$$
\mu = \lambda \int (1- g(x)) \, dx
$$
where \(\lambda\) is the intensity of the model and
\(g(x)\) is the pair correlation function, and
the integral is taken over all two-dimensional vectors \(x\).
Values of \(\mu\) are dimensionless.
Larger positive values of \(\mu\) indicate stronger repulsion
between points.
The repulsiveness index was originally defined for
determinantal point processes, but the same definition can be applied
to other kinds of point process models. The repulsiveness index is
positive for a determinantal point process model, zero for a Poisson
process or spatial logistic regression model, negative for
a cluster process or Cox process, and typically positive for a
Gibbs process.
If the model is stationary, the result is a single number.
If the model is not stationary,
the result is a pixel image (obtained by multiplying
the spatially-varying intensity by the integral defined above).
For Gibbs models of class "ppm" the calculation uses the
Poisson-saddlepoint approximation to the pair correlation function,
and is only implemented for stationary unmarked processes.
For models of class "mppm" the result is a numeric vector
or a list of images, with one entry for each point pattern to which
the model was fitted.