zclustermodel: Cluster Point Process Model

View source: R/zclustermodel.R

zclustermodelR Documentation

Cluster Point Process Model

Description

Experimental code. Creates an object representing a cluster point process model. Typically used for theoretical calculations about such a model.

Usage

zclustermodel(name = "Thomas", ..., mu, kappa, scale)

Arguments

name

Name of the cluster process. One of "Thomas", "MatClust", "VarGamma" or "Cauchy".

...

Other arguments needed for the model.

mu

Mean cluster size. A single number, or a pixel image.

kappa

Parent intensity. A single number.

scale

Cluster scale parameter of the model.

Details

Experimental.

Will soon be deprecated in favour of clusterprocess.

Value

Object of the experimental class "zclustermodel".

Author(s)

\adrian

See Also

methods.zclustermodel

Examples

  m <- zclustermodel("Thomas", kappa=10, mu=5, scale=0.1)

spatstat.model documentation built on March 29, 2026, 9:07 a.m.