| Kmodel | R Documentation |
Returns the theoretical K function, L function or
pair correlation function of a point process model.
Kmodel(model, ...)
pcfmodel(model, ...)
Lmodel(model, ...)
model |
A point process model of some kind. |
... |
Ignored. |
For certain types of point process models, it is possible to
write down a mathematical expression for the K function
or the pair correlation function of the model.
The functions Kmodel, Lmodel and pcfmodel give the
theoretical K-function, L-function and pair correlation
function for a point process model.
The functions Kmodel, Lmodel and pcfmodel are generic,
with methods for the classes "kppm" (fitted cluster processes
and Cox processes), "ppm" (fitted Gibbs processes)
and "clusterprocess" (cluster process models with
specified values of the parameters).
The return value is a function in the R language,
which takes one argument r.
Evaluation of this function, on a numeric vector r,
yields values of the desired K function or pair correlation
function at these distance values.
A function in the R language,
which takes one argument r.
.
Kest or pcf
to estimate the K function or pair correlation function
nonparametrically from data.
Kmodel.kppm for the method for fitted cluster processes
and Cox processes.
Kmodel.clusterprocess for the method for
cluster process models with specified parameter values.
Kmodel.ppm for the method for fitted Gibbs processes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.