View source: R/clusterprocess.R
| Kmodel.clusterprocess | R Documentation |
Returns the theoretical K function, L function or
pair correlation function of a cluster point process model
with specified values of its parameters.
## S3 method for class 'clusterprocess'
Kmodel(model, ...)
## S3 method for class 'clusterprocess'
Lmodel(model, ...)
## S3 method for class 'clusterprocess'
pcfmodel(model, ...)
model |
Object of class |
... |
Arguments passed to other methods. |
For some point process models, it is possible to
write down a mathematical expression for the K function
or the pair correlation function of the model.
The commands Kmodel, Lmodel and pcfmodel are
generic, with methods for the classes "kppm" (fitted cluster processes
and Cox processes), "ppm" (fitted Gibbs processes),
and "clusterprocess" (theoretical cluster processes).
This page documents the methods for the class "clusterprocess".
An object of this class represents a
Neyman-Scott-Cox cluster point process model with specified values
of its parameters.
The return value is a function in the R language,
which takes one argument r.
Evaluation of this function, on a numeric vector r,
yields values of the desired K function or pair correlation
function at these distance values.
A function in the R language,
which takes one argument r.
clusterprocess.
Kest, Lest or pcf
to estimate the K function, L function
or pair correlation function nonparametrically from point pattern data.
Kmodel.kppm for the method for fitted cluster processes
and Cox processes.
Kmodel.ppm for the method for fitted Gibbs processes.
m <- clusterprocess("Thomas", kappa=10, mu=5, scale=0.1)
m2 <- clusterprocess("VarGamma", kappa=10, mu=10, scale=0.1, nu=0.7)
m
m2
g <- pcfmodel(m)
g(0.2)
g2 <- pcfmodel(m2)
g2(1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.