intensity.kppm: Intensity of Fitted Point Process Model (Cluster Process or...

View source: R/kppm.R

intensity.kppmR Documentation

Intensity of Fitted Point Process Model (Cluster Process or Cox Process)

Description

Computes the intensity of a fitted point process model (Neyman-Scott cluster process or Cox process).

Usage

 ## S3 method for class 'kppm'
intensity(X, ...)

Arguments

X

A fitted point process model (object of class "kppm").

...

Arguments passed to predict.ppm in some cases. See Details.

Details

This is a method for the generic function intensity for fitted point process models of class "kppm". An object of this class is created by the model-fitting function kppm and represents a fitted Neyman-Scott cluster process or Cox process model (Baddeley, Rubak and Turner, 2015, chapter 12).

The intensity of a point process model is the expected number of random points per unit area.

The result of intensity.kppm(X) is a numerical value if X is a stationary point process, and a pixel image if X is non-stationary. In the latter case, the resolution of the pixel image is controlled by the arguments ... which are passed to predict.ppm.

Value

A numeric value (if the model is stationary) or a pixel image.

Author(s)

\spatstatAuthors

.

References

\baddrubaturnbook

See Also

intensity, intensity.ppm

Examples

   m <- kppm(redwood ~ 1, "LGCP")
   intensity(m)

spatstat.model documentation built on July 28, 2026, 9:06 a.m.