| intensity.kppm | R Documentation |
Computes the intensity of a fitted point process model (Neyman-Scott cluster process or Cox process).
## S3 method for class 'kppm'
intensity(X, ...)
X |
A fitted point process model (object of class |
... |
Arguments passed to |
This is a method for the generic function intensity
for fitted point process models of class "kppm". An object of
this class is created by the model-fitting function kppm and
represents a fitted Neyman-Scott cluster process or Cox
process model (Baddeley, Rubak and Turner, 2015, chapter 12).
The intensity of a point process model is the expected number of random points per unit area.
The result of intensity.kppm(X) is a numerical value if X
is a stationary point process, and a pixel image if X
is non-stationary. In the latter case, the resolution of the pixel
image is controlled by the arguments ... which are passed
to predict.ppm.
A numeric value (if the model is stationary) or a pixel image.
.
intensity,
intensity.ppm
m <- kppm(redwood ~ 1, "LGCP")
intensity(m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.