| intensity.mppm | R Documentation |
Computes the intensity of a point process model fitted to multiple point patterns.
## S3 method for class 'mppm'
intensity(X, ...)
X |
A point process model fitted to multiple point pattern
datasets (object of class |
... |
Arguments passed to |
This is a method for the generic function
intensity for objects of class "mppm".
Such an object is created
by the model-fitting function mppm and represents
a point process model fitted to multiple point patterns.
The intensity of a point process model is the expected number of random points per unit area.
For each of the original point pattern datasets to which X was
fitted, the intensity of the fitted model will be computed
by intensity.ppm. These results will be coerced to
an appropriate format.
For stationary point process models,
the result of intensity.mppm(X)
will be a numeric vector giving the fitted intensity
values for each dataset, or (if the data were multitype point
patterns) a numeric matrix giving the fitted
intensity for each type of point for each dataset.
For non-stationary models, the result of intensity.mppm(X) will
be a list of pixel images giving the fitted intensity for each dataset,
or a list of lists of pixel images giving the fitted intensity of each
type of point for each dataset.
When additional arguments ...
are given, the result will be a list containing the results of
intensity.ppm for each dataset.
A numeric vector or matrix, a list of pixel images, or a list of lists of pixel images, or a list containing data of another type.
.
intensity,
intensity.ppm.
Type methods(intensity) to see methods for other classes.
h <- hyperframe(Bugs=waterstriders)
m1 <- mppm(Bugs ~ 1, data=h)
intensity(m1)
mx <- mppm(Bugs ~ x, data=h)
intensity(mx)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.