persist: Spatial Persistence Index

View source: R/kppm.R

persistR Documentation

Spatial Persistence Index

Description

Given a cluster process model, calculate the spatial persistence index v for the model over a specified window.

Usage

persist(object, W=Window(object))

Arguments

object

Clustered point process model. Either an object of class "kppm" representing a cluster point process or Cox point process model fitted to point pattern data, or an object of class "clusterprocess" representing a cluster process model with specified parameters.

W

Spatial region (object of class "owin") for which the persistence index should be calculated. Default is the window in which the original point pattern dataset was observed.

Details

The spatial persistence index of a cluster process model is a numerical index which expresses the spatial scale of the model relative to the size of the window in which the data were observed. It is defined as (Baddeley et al., 2022, section 10.2)

v = \frac{g(d) - 1}{g(0)-1}

where g is the pair correlation function of the cluster process, and d is the diameter of the window.

The index v is dimensionless and takes values between 0 and 1. It depends on both the fitted cluster process, and on the window in which the original data were observed. (The user can specify a different observation window W, for which the persistence index should be calculated.)

The spatial persistence index effectively measures the size of a typical cluster in the cluster process (observed within the observation window) as a fraction of the size of the observation window. Values of v close to 1 indicate that the clusters are so large that the model (observed within the observation window) is effectively a mixed Poisson process.

The spatial persistence index is calculated for the window specified by the argument W. For a model of class "kppm", the default for W is the window of the original point pattern dataset to which the model was fitted. For a model of class "clusterprocess", the argument W must be provided.

Value

A single numerical value between 0 and 1.

Author(s)

\adrian

.

References

Baddeley, A., Davies, T.M., Hazelton, M.L., Rakshit, S. and Turner, R. (2022) Fundamental problems in fitting spatial cluster process models. Spatial Statistics 52, 100709. DOI: 10.1016/j.spasta.2022.100709

See Also

psib, panysib, clusterstrength, repul

Examples

  #' Fit model to NON-clustered region of full redwood data
  X <- redwoodfull[redwoodfull.extra$regionI]
  fit <- kppm(X)

  persist(fit)

  psib(fit)
  panysib(fit)

  ## conclusion: fitted model is approximately a mixed Poisson process

  #' Create a Thomas model
  m <- clusterprocess("Thomas", kappa=10, mu=5, scale=0.1)
  persist(m, square(1))

spatstat.model documentation built on March 29, 2026, 9:07 a.m.