| repul | R Documentation |
Computes a measure of the degree of repulsion between points in a point process model.
repul(model, ...)
## S3 method for class 'dppm'
repul(model, ...)
## S3 method for class 'detpointprocfamily'
repul(model, ...)
## S3 method for class 'clusterprocess'
repul(model, ...)
## S3 method for class 'kppm'
repul(model, ...)
## S3 method for class 'ppm'
repul(model, ...)
## S3 method for class 'slrm'
repul(model, ...)
## S3 method for class 'rppm'
repul(model, ...)
## S3 method for class 'mppm'
repul(model, ...)
model |
A fitted point process model
(object of class |
... |
Ignored. |
The repulsiveness index \mu of a
point process model was defined by Lavancier, \Moller and Rubak (2015) as
\mu = \lambda \int (1- g(x)) \, dx
where \lambda is the intensity of the model and
g(x) is the pair correlation function, and
the integral is taken over all two-dimensional vectors x.
Values of \mu are dimensionless.
Larger positive values of \mu indicate stronger repulsion
between points.
The repulsiveness index was originally defined for determinantal point processes, but the same definition can be applied to other kinds of point process models. The repulsiveness index is positive for a determinantal point process model, zero for a Poisson process or spatial logistic regression model, negative for a cluster process or Cox process, and typically positive for a Gibbs process.
If the model is stationary, the result is a single number.
If the model is not stationary, the result is a pixel image (obtained by multiplying the spatially-varying intensity by the integral defined above).
For Gibbs models of class "ppm" the calculation uses the
Poisson-saddlepoint approximation to the pair correlation function,
and is only implemented for stationary unmarked processes.
For models of class "mppm" the result is a numeric vector
or a list of images, with one entry for each point pattern to which
the model was fitted.
A numeric value or a pixel image.
.
Lavancier, F., \Moller, J. and Rubak, E. (2015), Determinantal point process models and statistical inference. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 77, 853–877.
dppm,
psib.
jpines <- residualspaper$Fig1
fit <- dppm(jpines ~ 1, dppGauss)
repul(fit)
m <- dppGauss(lambda=10, alpha=0.1, d=2)
repul(m)
repul(kppm(redwood ~ 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.